@@ -8,24 +8,25 @@
     :copyright: (c) 2013-present by Abhinav Singh and contributors.
     :license: BSD, see LICENSE for more details.
 """
+import ssl
 import queue
+import socket
 import ipaddress
+from typing import TYPE_CHECKING, Any, Dict, List, Tuple, Union
 
-from typing import TYPE_CHECKING, Dict, Any, List, Union
 
-from typing_extensions import Protocol
-
-if TYPE_CHECKING:
-    DictQueueType = queue.Queue[Dict[str, Any]]    # pragma: no cover
+if TYPE_CHECKING:   # pragma: no cover
+    DictQueueType = queue.Queue[Dict[str, Any]]
 else:
     DictQueueType = queue.Queue
 
 
-class HasFileno(Protocol):
-    def fileno(self) -> int:
-        ...     # pragma: no cover
-
-
-Readables = List[Union[int, HasFileno]]
-Writables = List[Union[int, HasFileno]]
+Selectable = int
+Selectables = List[Selectable]
+SelectableEvents = Dict[Selectable, int]    # Values are event masks
+Readables = Selectables
+Writables = Selectables
+Descriptors = Tuple[Readables, Writables]
 IpAddress = Union[ipaddress.IPv4Address, ipaddress.IPv6Address]
+TcpOrTlsSocket = Union[ssl.SSLSocket, socket.socket]
+HostPort = Tuple[str, int]
